@@ -16,7 +16,6 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
 #include "periodictablestates.h"
 
 #include "psetables.h"
@@ -24,8 +23,8 @@
 #include <prefs.h>
 
 PeriodicTableStates::PeriodicTableStates(
-    const QList< ElementItem* > elementItemList,
-    const QList< NumerationItem* > numerationItemList)
+    const QList<ElementItem*> elementItemList,
+    const QList<NumerationItem*> numerationItemList)
         : m_elementItemList(elementItemList),
         m_numerationItemList(numerationItemList),
         m_width(42), m_height(42)  // Some space between the elements (px40) looks nice.
@@ -37,37 +36,38 @@ PeriodicTableStates::PeriodicTableStates(
     for (int tableIndex = 0; tableIndex < pseTables::instance()->tables().count(); ++tableIndex) {
         m_tableStatesList << new QState(m_stateSwitcher);
 
-        setNumerationItemPositions( tableIndex );
+        setNumerationItemPositions(tableIndex);
 
-        setElementItemPositions( tableIndex );
+        setElementItemPositions(tableIndex);
 
-        m_stateSwitcher->addState(m_tableStatesList.at( tableIndex ), m_group, tableIndex);
+        m_stateSwitcher->addState(m_tableStatesList.at(tableIndex), m_group, tableIndex);
     }
 
-    m_stateSwitcher->setInitialState( m_tableStatesList.at( Prefs::table() ) );
-    m_states.setInitialState( m_stateSwitcher );
+    m_stateSwitcher->setInitialState(m_tableStatesList.at(Prefs::table()));
+    m_states.setInitialState(m_stateSwitcher);
     m_states.start();
 }
 
-void PeriodicTableStates::setNumerationItemPositions( const int &tableIndex )
+void PeriodicTableStates::setNumerationItemPositions(const int &tableIndex)
 {
-    hideAllNumerationItems( tableIndex );
+    hideAllNumerationItems(tableIndex);
 
-    for (int x = 0; x < maxNumerationItemXCoordinate( tableIndex ); ++x) {
-        int numerationId = pseTables::instance()->getTabletype( tableIndex )->numerationAtPos( x );
+    for (int x = 0; x < maxNumerationItemXCoordinate(tableIndex); ++x) {
+        int numerationId = pseTables::instance()->getTabletype(tableIndex)->numerationAtPos(x);
 
-        if ( numerationId >= 0 ) {
-            m_tableStatesList.at( tableIndex )->assignProperty(m_numerationItemList.at(numerationId), "pos",
-                    QPointF( x * m_width, - m_height * 3 / 4));
-            addElementAnimation( m_numerationItemList.at(numerationId), x );
+        if (numerationId >= 0) {
+            m_tableStatesList.at(tableIndex)->assignProperty(m_numerationItemList.at(numerationId), "pos",
+                    QPointF(x * m_width, - m_height * 3 / 4));
+            addElementAnimation(m_numerationItemList.at(numerationId), x);
         }
     }
 }
 
 void PeriodicTableStates::hideAllNumerationItems(const int &tableIndex)
 {
-    foreach( NumerationItem *item, m_numerationItemList)
-        m_tableStatesList.at( tableIndex )->assignProperty( item, "pos", QPointF( hiddenPoint() ));
+    foreach (NumerationItem *item, m_numerationItemList) {
+        m_tableStatesList.at(tableIndex)->assignProperty(item, "pos", QPointF(hiddenPoint()));
+    }
 }
 
 QPoint PeriodicTableStates::hiddenPoint() const
@@ -77,7 +77,7 @@ QPoint PeriodicTableStates::hiddenPoint() const
 
 int PeriodicTableStates::maxNumerationItemXCoordinate(const int &tableIndex)
 {
-    const int maxTableLenght = pseTables::instance()->getTabletype( tableIndex )->tableSize().x();
+    const int maxTableLenght = pseTables::instance()->getTabletype(tableIndex)->tableSize().x();
 
     return maxTableLenght > m_numerationItemList.count() ?
            maxTableLenght : m_numerationItemList.count();
@@ -85,32 +85,33 @@ int PeriodicTableStates::maxNumerationItemXCoordinate(const int &tableIndex)
 
 void PeriodicTableStates::addElementAnimation(QGraphicsObject *object, int duration)
 {
-    QPropertyAnimation *anim = new QPropertyAnimation( object, "pos");
-    anim->setDuration( 1600 + duration * 2);
+    QPropertyAnimation *anim = new QPropertyAnimation(object, "pos");
+    anim->setDuration(1600 + duration * 2);
     anim->setEasingCurve(QEasingCurve::InOutExpo);
-    m_group->addAnimation( anim );
+    m_group->addAnimation(anim);
 }
 
 void PeriodicTableStates::setElementItemPositions(const int &tableIndex)
 {
     for (int i = 0; i < m_elementItemList.size(); ++i) {
-        const int elementNumber = m_elementItemList.at( i )->data(0).toInt();
-        QPoint itemPosition = pseTables::instance()->getTabletype( tableIndex )->elementCoords( elementNumber );
+        const int elementNumber = m_elementItemList.at(i)->data(0).toInt();
+        QPoint itemPosition = pseTables::instance()->getTabletype(tableIndex)->elementCoords(elementNumber);
 
         // put the not needed elements a bit away
-        if ( itemPosition.x() < 0)
+        if (itemPosition.x() < 0) {
             itemPosition = hiddenPoint();
+        }
 
-        m_tableStatesList.at( tableIndex )->assignProperty( m_elementItemList.at( i ), "pos",
-                QPointF( (itemPosition.x() ) * m_width, (itemPosition.y()) * m_height));
+        m_tableStatesList.at(tableIndex)->assignProperty(m_elementItemList.at(i), "pos",
+                QPointF((itemPosition.x()) * m_width, (itemPosition.y()) * m_height));
 
-        addElementAnimation( m_elementItemList.at( i ), i);
+        addElementAnimation(m_elementItemList.at(i), i);
     }
 }
 
-QRectF PeriodicTableStates::pseRect( const int &tableIndex ) const
+QRectF PeriodicTableStates::pseRect(const int &tableIndex) const
 {
-    const QPoint maxTableCoords = pseTables::instance()->getTabletype( tableIndex )->tableSize();
+    const QPoint maxTableCoords = pseTables::instance()->getTabletype(tableIndex)->tableSize();
 
     const int x = maxTableCoords.x();
 
@@ -120,9 +121,9 @@ QRectF PeriodicTableStates::pseRect( const int &tableIndex ) const
     return QRectF(0, -m_height, x * m_width, y * m_height);
 }
 
-void PeriodicTableStates::setTableState( const int &tableIndex )
+void PeriodicTableStates::setTableState(const int &tableIndex)
 {
-    m_stateSwitcher->switchToState( tableIndex );
+    m_stateSwitcher->switchToState(tableIndex);
 }
 
 PeriodicTableStates::~PeriodicTableStates()
